@@ -88,12 +88,14 @@ impl Drawing {
     where
         T: Into<Shape>,
     {
-        let mut s: Shape = shape.into();
-        s.update_pos(s.pos.pos + self.position);
-        self.shapes.push(s);
+        self.shapes.push(shape.into());
         self
     }
 
+    pub fn into_embedded(self) -> EmbeddedDrawing {
+        EmbeddedDrawing::new(self)
+    }
+
     /// Get access to this drawing's shapes.
     /// ```
     /// # use dessin::{
